@@ -5,8 +5,7 @@ use Carp ();
 
 require Email::Simple;
 
-our $VERSION = '2.200_02';
-$VERSION = eval $VERSION;
+$Email::Simple::Header::VERSION = '2.103';
 
 =head1 NAME
 
@@ -72,17 +71,14 @@ sub _header_to_list {
 
   while ($$head =~ m/\G(.+?)$crlf/go) {
     local $_ = $1;
-
-    if (/^\s+/ or not /^([^:]+):\s*(.*)/) {
+    if (s/^\s+// or not /^([^:]+):\s*(.*)/) {
       # This is a continuation line. We fold it onto the end of
       # the previous header.
       next if !@headers;  # Well, that sucks.  We're continuing nothing?
 
-      (my $trimmed = $_) =~ s/^\s+//;
-      $headers[-1][0] .= $headers[-1][0] =~ /\S/ ? " $trimmed" : $trimmed;
-      $headers[-1][1] .= "$mycrlf$_";
+      $headers[-1] .= $headers[-1] =~ /\S/ ? " $_" : $_;
     } else {
-      push @headers, $1, [ $2, $_ ];
+      push @headers, $1, $2;
     }
   }
 
@@ -119,13 +115,11 @@ sub as_string {
   };
 
   for (my $i = 0; $i < @$headers; $i += 2) {
-    if (ref $headers->[ $i + 1 ]) {
-      $header_str .= $headers->[ $i + 1 ][1] . $self->crlf;
-    } else {
-      my $header = "$headers->[$i]: $headers->[$i + 1]";
+    my $header = "$headers->[$i]: $headers->[$i + 1]";
 
-      $header_str .= $self->_fold($header, $fold_arg);
-    }
+    $header_str .= lc $headers->[$i] eq 'content-type'
+                 ? $header . $self->crlf
+                 : $self->_fold($header, $fold_arg);
   }
 
   return $header_str;
@@ -156,9 +150,7 @@ they appear in the header.
 sub header_pairs {
   my ($self) = @_;
 
-  my @pairs = map {; _str_value($_) } @{ $self->{headers} };
-
-  return @pairs;
+  return @{ $self->{headers} };
 }
 
 =head2 header
@@ -171,8 +163,6 @@ named field does not appear in the header, this method returns false.
 
 =cut
 
-sub _str_value { return ref $_[0] ? $_[0][0] : $_[0] }
-
 sub header {
   my ($self, $field) = @_;
 
@@ -180,11 +170,11 @@ sub header {
   my $lc_field = lc $field;
 
   if (wantarray) {
-    return map { _str_value($headers->[ $_ * 2 + 1 ]) }
+    return map { @$headers[ $_ * 2 + 1 ] }
       grep { lc $headers->[ $_ * 2 ] eq $lc_field } 0 .. int($#$headers / 2);
   } else {
     for (0 .. int($#$headers / 2)) {
-      return _str_value($headers->[ $_ * 2 + 1 ]) if lc $headers->[ $_ * 2 ] eq $lc_field;
+      return $headers->[ $_ * 2 + 1 ] if lc $headers->[ $_ * 2 ] eq $lc_field;
     }
     return;
   }
